@@ -12,7 +12,7 @@
 #ifndef _TIPC_MSG_H
 #define _TIPC_MSG_H
 
-struct nlmsghdr *msg_init(char *buf, int cmd);
+struct nlmsghdr *msg_init(int cmd);
 int msg_doit(struct nlmsghdr *nlh, mnl_cb_t callback, void *data);
 int msg_dumpit(struct nlmsghdr *nlh, mnl_cb_t callback, void *data);
 int parse_attrs(const struct nlattr *attr, void *data);
